@@ -15,6 +15,8 @@ from octavia_lib.common import constants
 
 # TODO(mjozefcz): Use those variables from neutron-lib once released.
 LRP_PREFIX = "lrp-"
+OVN_NAME_PREFIX = "neutron-"
+LB_HM_PORT_PREFIX = "ovn-lb-hm-"
 LB_VIP_PORT_PREFIX = "ovn-lb-vip-"
 OVN_PORT_NAME_EXT_ID_KEY = 'neutron:port_name'
 OVN_ROUTER_NAME_EXT_ID_KEY = 'neutron:router_name'
@@ -23,12 +25,14 @@ OVN_PORT_FIP_EXT_ID_KEY = 'neutron:port_fip'
 OVN_SUBNET_EXT_ID_KEY = 'neutron:subnet_id'
 OVN_SUBNET_EXT_IDS_KEY = 'neutron:subnet_ids'
 OVN_NETWORK_NAME_EXT_ID_KEY = 'neutron:network_name'
+OVN_PROJECT_EXT_ID_KEY = 'neutron:project_id'
 OVN_SG_IDS_EXT_ID_KEY = 'neutron:security_group_ids'
 OVN_DEVICE_OWNER_EXT_ID_KEY = 'neutron:device_owner'
 OVN_FIP_EXT_ID_KEY = 'neutron:fip_id'
 OVN_FIP_PORT_EXT_ID_KEY = 'neutron:fip_port_id'
 OVN_GW_PORT_EXT_ID_KEY = 'neutron:gw_port_id'
 OVN_PORT_CIDR_EXT_ID_KEY = 'neutron:cidrs'
+OVN_MEMBER_STATUS_KEY = 'neutron:member_status'
 
 LB_EXT_IDS_LS_REFS_KEY = 'ls_refs'
 LB_EXT_IDS_LR_REF_KEY = 'lr_ref'
@@ -36,6 +40,7 @@ LB_EXT_IDS_POOL_PREFIX = 'pool_'
 LB_EXT_IDS_LISTENER_PREFIX = 'listener_'
 LB_EXT_IDS_MEMBER_PREFIX = 'member_'
 LB_EXT_IDS_HM_KEY = 'octavia:healthmonitor'
+LB_EXT_IDS_HMS_KEY = 'octavia:healthmonitors'
 LB_EXT_IDS_VIP_KEY = 'neutron:vip'
 LB_EXT_IDS_VIP_FIP_KEY = 'neutron:vip_fip'
 LB_EXT_IDS_VIP_PORT_ID_KEY = 'neutron:vip_port_id'
@@ -101,3 +106,7 @@ LB_SELECTION_FIELDS_MAP = {
     constants.LB_ALGORITHM_SOURCE_IP: ["ip_src", "ip_dst"],
     None: ["ip_src", "ip_dst", "tp_src", "tp_dst"],
 }
+
+# HM events status
+HM_EVENT_MEMBER_PORT_ONLINE = ['online']
+HM_EVENT_MEMBER_PORT_OFFLINE = ['offline']
