@@ -355,7 +355,8 @@ class TestOvnProviderDriver(ovn_base.TestOvnOctaviaBase):
                 'protocol_port': self.ref_member.protocol_port,
                 'pool_id': self.ref_member.pool_id,
                 'admin_state_up': self.update_member.admin_state_up,
-                'old_admin_state_up': self.ref_member.admin_state_up}
+                'old_admin_state_up': self.ref_member.admin_state_up,
+                'subnet_id': self.ref_member.subnet_id}
         expected_dict = {'type': ovn_const.REQ_TYPE_MEMBER_UPDATE,
                          'info': info}
         self.driver.member_update(self.ref_member, self.update_member)
@@ -369,7 +370,8 @@ class TestOvnProviderDriver(ovn_base.TestOvnOctaviaBase):
                 'protocol_port': self.ref_member.protocol_port,
                 'pool_id': self.ref_member.pool_id,
                 'admin_state_up': self.update_member.admin_state_up,
-                'old_admin_state_up': self.ref_member.admin_state_up}
+                'old_admin_state_up': self.ref_member.admin_state_up,
+                'subnet_id': self.ref_member.subnet_id}
         expected_dict = {'type': ovn_const.REQ_TYPE_MEMBER_UPDATE,
                          'info': info}
         member = copy.copy(self.ref_member)
@@ -385,7 +387,8 @@ class TestOvnProviderDriver(ovn_base.TestOvnOctaviaBase):
                 'address': self.ref_member.address,
                 'protocol_port': self.ref_member.protocol_port,
                 'pool_id': self.ref_member.pool_id,
-                'old_admin_state_up': self.ref_member.admin_state_up}
+                'old_admin_state_up': self.ref_member.admin_state_up,
+                'subnet_id': self.ref_member.subnet_id}
         expected_dict = {'type': ovn_const.REQ_TYPE_MEMBER_UPDATE,
                          'info': info}
         member = copy.copy(self.ref_member)
@@ -404,22 +407,6 @@ class TestOvnProviderDriver(ovn_base.TestOvnOctaviaBase):
                                         [self.ref_member, self.update_member])
         self.assertEqual(self.mock_add_request.call_count, 3)
 
-    def test_member_batch_update_member_delete(self):
-        info_md = {
-            'id': self.ref_member.member_id,
-            'address': mock.ANY,
-            'protocol_port': mock.ANY,
-            'pool_id': self.ref_member.pool_id,
-            'subnet_id': self.ref_member.subnet_id}
-        expected_dict_md = {
-            'type': ovn_const.REQ_TYPE_MEMBER_DELETE,
-            'info': info_md}
-        expected = [
-            mock.call(expected_dict_md)]
-        self.driver.member_batch_update(self.pool_id, [])
-        self.assertEqual(self.mock_add_request.call_count, 1)
-        self.mock_add_request.assert_has_calls(expected)
-
     def test_member_batch_update_no_members(self):
         pool_key = 'pool_%s' % self.pool_id
         ovn_lb = copy.copy(self.ovn_lb)
@@ -448,26 +435,6 @@ class TestOvnProviderDriver(ovn_base.TestOvnOctaviaBase):
         self.driver.member_batch_update(self.pool_id, [self.ref_member])
         self.assertEqual(self.mock_add_request.call_count, 2)
 
-    def test_member_batch_update_toggle_admin_state_up(self):
-        info_mu = {
-            'id': self.ref_member.member_id,
-            'address': self.member_address,
-            'protocol_port': self.member_port,
-            'pool_id': self.ref_member.pool_id,
-            'subnet_id': self.ref_member.subnet_id,
-            'admin_state_up': False}
-        expected_dict_mu = {
-            'type': ovn_const.REQ_TYPE_MEMBER_UPDATE,
-            'info': info_mu}
-        expected = [
-            mock.call(expected_dict_mu)]
-        self.ref_member.admin_state_up = False
-        self.ref_member.address = self.member_address
-        self.ref_member.protocol_port = self.member_port
-        self.driver.member_batch_update(self.pool_id, [self.ref_member])
-        self.assertEqual(self.mock_add_request.call_count, 1)
-        self.mock_add_request.assert_has_calls(expected)
-
     def test_member_batch_update_missing_subnet_id(self):
         self.ref_member.subnet_id = None
         self.assertRaises(exceptions.UnsupportedOptionError,
@@ -903,31 +870,24 @@ class TestOvnProviderDriver(ovn_base.TestOvnOctaviaBase):
         self.driver.pool_delete(self.ref_pool)
         self.mock_add_request.assert_called_once_with(expected)
 
-    def test_pool_delete_with_members_and_hm(self):
-        self.ref_pool.healthmonitor = self.ref_health_monitor
+    def test_pool_delete_with_members(self):
         info = {'id': self.ref_pool.pool_id,
                 'protocol': self.ref_pool.protocol,
                 'loadbalancer_id': self.ref_pool.loadbalancer_id}
         expected = {'type': ovn_const.REQ_TYPE_POOL_DELETE,
                     'info': info}
-        info_hm = {'id': self.ref_pool.healthmonitor.healthmonitor_id,
-                   'pool_id': self.ref_pool.pool_id}
         info_member = {'id': self.ref_member.member_id,
                        'pool_id': self.ref_member.pool_id,
                        'subnet_id': self.ref_member.subnet_id,
                        'protocol_port': self.ref_member.protocol_port,
                        'address': self.ref_member.address}
-        expected_hm = {
-            'type': ovn_const.REQ_TYPE_HM_DELETE,
-            'info': info_hm}
         expected_members = {
             'type': ovn_const.REQ_TYPE_MEMBER_DELETE,
             'info': info_member}
         expected_members_dvr = {
             'type': ovn_const.REQ_TYPE_HANDLE_MEMBER_DVR,
             'info': mock.ANY}
-        calls = [mock.call(expected_hm),
-                 mock.call(expected_members),
+        calls = [mock.call(expected_members),
                  mock.call(expected_members_dvr),
                  mock.call(expected)]
         self.driver.pool_delete(self.ref_pool)
@@ -977,11 +937,13 @@ class TestOvnProviderDriver(ovn_base.TestOvnOctaviaBase):
 
     def test_create_vip_port(self):
         with mock.patch.object(clients, 'get_neutron_client'):
-            port_dict = self.driver.create_vip_port(self.loadbalancer_id,
-                                                    self.project_id,
-                                                    self.vip_dict)
+            port_dict, add_vip_dicts = (
+                self.driver.create_vip_port(self.loadbalancer_id,
+                                            self.project_id,
+                                            self.vip_dict, []))
             self.assertIsNotNone(port_dict.pop('vip_address', None))
             self.assertIsNotNone(port_dict.pop('vip_port_id', None))
+            self.assertEqual(len(add_vip_dicts), 0)
             # The network_driver function is mocked, therefore the
             # created port vip_address and vip_port_id are also mocked.
             # Check if it exists and move on.
@@ -998,7 +960,8 @@ class TestOvnProviderDriver(ovn_base.TestOvnOctaviaBase):
                 self.driver.create_vip_port,
                 self.loadbalancer_id,
                 self.project_id,
-                self.vip_dict)
+                self.vip_dict,
+                [])
 
     def test_health_monitor_create(self):
         info = {'id': self.ref_health_monitor.healthmonitor_id,
@@ -1083,8 +1046,7 @@ class TestOvnProviderDriver(ovn_base.TestOvnOctaviaBase):
         self.mock_add_request.assert_called_once_with(expected_dict)
 
     def test_health_monitor_delete(self):
-        info = {'id': self.ref_health_monitor.healthmonitor_id,
-                'pool_id': self.ref_health_monitor.pool_id}
+        info = {'id': self.ref_health_monitor.healthmonitor_id}
         expected_dict = {'type': ovn_const.REQ_TYPE_HM_DELETE,
                          'info': info}
         self.driver.health_monitor_delete(self.ref_health_monitor)
